@@ -1,9 +1,9 @@
 #
-# Copyright (c) 2004-2007 by the cairo perl team (see the file README)
+# Copyright (c) 2004-2008 by the cairo perl team (see the file README)
 #
 # Licensed under the LGPL, see LICENSE file for more information.
 #
-# $Header: /cvs/cairo/cairo-perl/Cairo.pm,v 1.27 2007/05/27 12:37:43 tsch Exp $
+# $Header: /cvs/cairo/cairo-perl/Cairo.pm,v 1.40 2008-04-19 16:38:51 tsch Exp $
 #
 
 package Cairo;
@@ -14,7 +14,7 @@ use DynaLoader;
 
 our @ISA = qw/DynaLoader/;
 
-our $VERSION = '1.041';
+our $VERSION = '1.060';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -49,7 +49,7 @@ Cairo - Perl interface to the cairo library
 
   $cr->show_page;
 
-  $surface->write_to_png ("output.png");
+  $surface->write_to_png ('output.png');
 
 =head1 ABSTRACT
 
@@ -393,6 +393,8 @@ C<$cr-E<gt>close_path>.
 
 =back
 
+=head4 $bool = $cr->has_current_point [1.6]
+
 =head4 ($x, $y) = $cr->get_current_point
 
 =head4 $cr->new_path
@@ -401,6 +403,8 @@ C<$cr-E<gt>close_path>.
 
 =head4 $cr->close_path
 
+=head4 ($x1, $y1, $x2, $y2) = $cr->path_extents [1.6]
+
 =head4 $cr->arc ($xc, $yc, $radius, $angle1, $angle2)
 
 =over
@@ -1031,6 +1035,403 @@ I<x> and I<y>.  Example:
 
 # --------------------------------------------------------------------------- #
 
+=head3 FreeType Fonts -- Font support for FreeType
+
+If your cairo library supports it, the FreeType integration allows you to load
+font faces from font files.  You can query for this capability with
+C<Cairo::HAS_FT_FONT>.  To actually use this, you'll need the L<Font::FreeType>
+module.
+
+=head4 my $face = Cairo::FtFontFace->create ($ft_face, $load_flags=0)
+
+=over
+
+=item $ft_face: I<Font::FreeType::Face>
+
+=item $load_flags: integer
+
+=back
+
+This method allows you to create a I<Cairo::FontFace> from a
+I<Font::FreeType::Face>.  To obtain the latter, you can for example load it
+from a file:
+
+  my $file = '/usr/share/fonts/truetype/ttf-bitstream-vera/Vera.ttf';
+  my $ft_face = Font::FreeType->new->face ($file);
+  my $face = Cairo::FtFontFace->create ($ft_face);
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
+=head2 Surfaces
+
+=head3 I<Cairo::Surface> -- Base class for surfaces
+
+=head4 $new = $old->create_similar ($content, $width, $height)
+
+=over
+
+=item $content: I<Cairo::Content>
+
+=item $width: integer
+
+=item $height: integer
+
+=back
+
+=head4 $status = $surface->status
+
+=head4 $surface->finish
+
+=head4 $surface->flush
+
+=head4 $font_options = $surface->get_font_options
+
+=head4 $content = $surface->get_content [1.2]
+
+=head4 $surface->mark_dirty
+
+=head4 $surface->mark_dirty_rectangle ($x, $y, $width, $height)
+
+=over
+
+=item $x: integer
+
+=item $y: integer
+
+=item $width: integer
+
+=item $height: integer
+
+=back
+
+=head4 $surface->set_device_offset ($x_offset, $y_offset)
+
+=over
+
+=item $x_offset: integer
+
+=item $y_offset: integer
+
+=back
+
+=head4 ($x_offset, $y_offset) = $surface->get_device_offset [1.2]
+
+=head4 $surface->set_fallback_resolution ($x_pixels_per_inch, $y_pixels_per_inch) [1.2]
+
+=over
+
+=item $x_pixels_per_inch: double
+
+=item $y_pixels_per_inch: double
+
+=back
+
+=head4 $type = $surface->get_type [1.2]
+
+=head4 $status = $surface->copy_page [1.6]
+
+=over
+
+=item $status: I<Cairo::Status>
+
+=back
+
+=head4 $status = $surface->show_page [1.6]
+
+=over
+
+=item $status: I<Cairo::Status>
+
+=back
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
+=head3 Image Surfaces -- Rendering to memory buffers
+
+=head4 $surface = Cairo::ImageSurface->create ($format, $width, $height)
+
+=over
+
+=item $format: I<Cairo::Format>
+
+=item $width: integer
+
+=item $height: integer
+
+=back
+
+=head4 $surface = Cairo::ImageSurface->create_for_data ($data, $format, $width, $height, $stride)
+
+=over
+
+=item $data: image data
+
+=item $format: I<Cairo::Format>
+
+=item $width: integer
+
+=item $height: integer
+
+=item $stride: integer
+
+=back
+
+=head4 $data = $surface->get_data [1.2]
+
+=head4 $format = $surface->get_format [1.2]
+
+=head4 $width = $surface->get_width
+
+=head4 $height = $surface->get_height
+
+=head4 $stride = $surface->get_stride [1.2]
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
+=head3 PDF Surfaces -- Rendering PDF documents
+
+=head4 $surface = Cairo::PdfSurface->create ($filename, $width_in_points, $height_in_points) [1.2]
+
+=over
+
+=item $filename: string
+
+=item $width_in_points: double
+
+=item $height_in_points: double
+
+=back
+
+=head4 $surface = Cairo::PdfSurface->create_for_stream ($callback, $callback_data, $width_in_points, $height_in_points) [1.2]
+
+=over
+
+=item $callback: L<Cairo::WriteFunc>
+
+=item $callback_data: scalar
+
+=item $width_in_points: double
+
+=item $height_in_points: double
+
+=back
+
+=head4 $surface->set_size ($width_in_points, $height_in_points) [1.2]
+
+=over
+
+=item $width_in_points: double
+
+=item $height_in_points: double
+
+=back
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
+=head3 PNG Support -- Reading and writing PNG images
+
+=head4 $surface = Cairo::ImageSurface->create_from_png ($filename)
+
+=over
+
+=item $filename: string
+
+=back
+
+=head4 Cairo::ReadFunc: $data = sub { my ($callback_data, $length) = @_; }
+
+=over
+
+=item $data: binary image data, of length $length
+
+=item $callback_data: scalar, user data
+
+=item $length: integer, bytes to read
+
+=back
+
+=head4 $surface = Cairo::ImageSurface->create_from_png_stream ($callback, $callback_data)
+
+=over
+
+=item $callback: L<Cairo::ReadFunc>
+
+=item $callback_data: scalar
+
+=back
+
+=head4 $status = $surface->write_to_png ($filename)
+
+=over
+
+=item $filename: string
+
+=back
+
+=head4 Cairo::WriteFunc: sub { my ($callback_data, $data) = @_; }
+
+=over
+
+=item $callback_data: scalar, user data
+
+=item $data: binary image data, to be written
+
+=back
+
+=head4 $status = $surface->write_to_png_stream ($callback, $callback_data)
+
+=over
+
+=item $callback: L<Cairo::WriteFunc>
+
+=item $callback_data: scalar
+
+=back
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
+=head3 PostScript Surfaces -- Rendering PostScript documents
+
+=head4 $surface = Cairo::PsSurface->create ($filename, $width_in_points, $height_in_points) [1.2]
+
+=over
+
+=item $filename: string
+
+=item $width_in_points: double
+
+=item $height_in_points: double
+
+=back
+
+=head4 $surface = Cairo::PsSurface->create_for_stream ($callback, $callback_data, $width_in_points, $height_in_points) [1.2]
+
+=over
+
+=item $callback: L<Cairo::WriteFunc>
+
+=item $callback_data: scalar
+
+=item $width_in_points: double
+
+=item $height_in_points: double
+
+=back
+
+=head4 $surface->set_size ($width_in_points, $height_in_points) [1.2]
+
+=over
+
+=item $width_in_points: double
+
+=item $height_in_points: double
+
+=back
+
+=head4 $surface->dsc_begin_setup [1.2]
+
+=head4 $surface->dsc_begin_page_setup [1.2]
+
+=head4 $surface->dsc_comment ($comment) [1.2]
+
+=over
+
+=item $comment: string
+
+=back
+
+=head4 $surface->restrict_to_level ($level) [1.6]
+
+=over
+
+=item $level: I<Cairo::PsLevel>
+
+=back
+
+=head4 @levels = Cairo::PsSurface::get_levels [1.6]
+
+=head4 $string = Cairo::PsSurface::level_to_string ($level) [1.6]
+
+=over
+
+=item $level: I<Cairo::PsLevel>
+
+=back
+
+=head4 $surface->set_eps ($eps) [1.6]
+
+=over
+
+=item $eps: boolean
+
+=back
+
+=head4 $eps = $surface->get_eps [1.6]
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
+=head3 SVG Surfaces -- Rendering SVG documents
+
+=head4 $surface = Cairo::SvgSurface->create ($filename, $width_in_points, $height_in_points) [1.2]
+
+=over
+
+=item $filename: string
+
+=item $width_in_points: double
+
+=item $height_in_points: double
+
+=back
+
+=head4 $surface = Cairo::SvgSurface->create_for_stream ($callback, $callback_data, $width_in_points, $height_in_points) [1.2]
+
+=over
+
+=item $callback: L<Cairo::WriteFunc>
+
+=item $callback_data: scalar
+
+=item $width_in_points: double
+
+=item $height_in_points: double
+
+=back
+
+=head4 $surface->restrict_to_version ($version) [1.2]
+
+=over
+
+=item $version: I<Cairo::SvgVersion>
+
+=back
+
+=head4 @versions = Cairo::SvgSurface::get_versions [1.2]
+
+=head4 $string = Cairo::SvgSurface::version_to_string ($version) [1.2]
+
+=over
+
+=item $version: I<Cairo::SvgVersion>
+
+=back
+
+=cut
+
+# --------------------------------------------------------------------------- #
+
 =head2 Utilities
 
 =head3 Version Information -- Run-time and compile-time version checks.
@@ -1053,6 +1454,16 @@ I<x> and I<y>.  Example:
 
 =back
 
+=head4 $stride = Cairo::Format::stride_for_width ($format, $width) [1.6]
+
+=over
+
+=item $format: I<Cairo::Format>
+
+=item $width: integer
+
+=back
+
 =cut
 
 # --------------------------------------------------------------------------- #
@@ -1083,6 +1494,6 @@ Contains the reference manual
 
 =head1 COPYRIGHT
 
-Copyright (C) 2004-2007 by the cairo perl team
+Copyright (C) 2004-2008 by the cairo perl team
 
 =cut
