@@ -3,13 +3,17 @@
  *
  * Licensed under the LGPL, see LICENSE file for more information.
  *
- * $Header: /cvs/cairo/cairo-perl/cairo-perl-private.h,v 1.4 2006/08/10 17:34:40 tsch Exp $
+ * $Header: /cvs/cairo/cairo-perl/cairo-perl-private.h,v 1.6 2007-09-30 12:54:32 tsch Exp $
  *
  */
 
 #ifndef _CAIRO_PERL_PRIVATE_H_
 #define _CAIRO_PERL_PRIVATE_H_
 
+#include "ppport.h"
+
+void * cairo_perl_alloc_temp (int nbytes);
+
 void cairo_perl_set_isa (const char * child_package, const char * parent_package);
 
 cairo_matrix_t * cairo_perl_copy_matrix (cairo_matrix_t *matrix);
@@ -22,4 +26,11 @@ const char * cairo_perl_package_table_lookup (void *pointer);
 
 #endif
 
+#define CAIRO_PERL_CHECK_STATUS(status)				\
+	if (CAIRO_STATUS_SUCCESS != status) {			\
+		SV *errsv = get_sv ("@", TRUE);			\
+		sv_setsv (errsv, newSVCairoStatus (status));	\
+		croak (Nullch);					\
+	}
+
 #endif /* _CAIRO_PERL_PRIVATE_H_ */
